@@ -2,16 +2,15 @@ require 'mocha/ruby_version'
 require 'metaclass'
 
 module Mocha
-
   class ClassMethod
-
     PrependedModule = Class.new(Module)
 
     attr_reader :stubbee, :method
 
     def initialize(stubbee, method)
       @stubbee = stubbee
-      @original_method, @original_visibility = nil, nil
+      @original_method = nil
+      @original_visibility = nil
       @method = PRE_RUBY_V19 ? method.to_s : method.to_sym
     end
 
@@ -24,9 +23,8 @@ module Mocha
       remove_new_method
       restore_original_method
       mock.unstub(method.to_sym)
-      unless mock.any_expectations?
-        reset_mocha
-      end
+      return if mock.any_expectations?
+      reset_mocha
     end
 
     def mock
@@ -38,21 +36,22 @@ module Mocha
     end
 
     def hide_original_method
-      if @original_visibility = method_visibility(method)
-        begin
-          if RUBY_V2_PLUS
-            @definition_target = PrependedModule.new
-            stubbee.__metaclass__.__send__ :prepend, @definition_target
-          else
-            @original_method = stubbee._method(method)
-            if @original_method && @original_method.owner == stubbee.__metaclass__
-              stubbee.__metaclass__.send(:remove_method, method)
-            end
+      return unless (@original_visibility = method_visibility(method))
+      begin
+        if RUBY_V2_PLUS
+          @definition_target = PrependedModule.new
+          stubbee.__metaclass__.__send__ :prepend, @definition_target
+        else
+          @original_method = stubbee._method(method)
+          if @original_method && @original_method.owner == stubbee.__metaclass__
+            stubbee.__metaclass__.send(:remove_method, method)
           end
-        rescue NameError
-          # deal with nasties like ActiveRecord::Associations::AssociationProxy
         end
+      # rubocop:disable Lint/HandleExceptions
+      rescue NameError
+        # deal with nasties like ActiveRecord::Associations::AssociationProxy
       end
+      # rubocop:enable Lint/HandleExceptions
     end
 
     def define_new_method
@@ -61,9 +60,8 @@ module Mocha
           mocha.method_missing(:#{method}, *args, &block)
         end
       CODE
-      if @original_visibility
-        Module.instance_method(@original_visibility).bind(definition_target).call(method)
-      end
+      return unless @original_visibility
+      Module.instance_method(@original_visibility).bind(definition_target).call(method)
     end
 
     def remove_new_method
@@ -71,26 +69,24 @@ module Mocha
     end
 
     def restore_original_method
-      unless RUBY_V2_PLUS
-        if @original_method && @original_method.owner == stubbee.__metaclass__
-          if PRE_RUBY_V19
-            original_method = @original_method
-            stubbee.__metaclass__.send(:define_method, method) do |*args, &block|
-              original_method.call(*args, &block)
-            end
-          else
-            stubbee.__metaclass__.send(:define_method, method, @original_method)
+      return if RUBY_V2_PLUS
+      if @original_method && @original_method.owner == stubbee.__metaclass__
+        if PRE_RUBY_V19
+          original_method = @original_method
+          stubbee.__metaclass__.send(:define_method, method) do |*args, &block|
+            original_method.call(*args, &block)
           end
-        end
-        if @original_visibility
-          Module.instance_method(@original_visibility).bind(stubbee.__metaclass__).call(method)
+        else
+          stubbee.__metaclass__.send(:define_method, method, @original_method)
         end
       end
+      return unless @original_visibility
+      Module.instance_method(@original_visibility).bind(stubbee.__metaclass__).call(method)
     end
 
     def matches?(other)
-      return false unless (other.class == self.class)
-      (stubbee.object_id == other.stubbee.object_id) and (method == other.method)
+      return false unless other.class == self.class
+      (stubbee.object_id == other.stubbee.object_id) && (method == other.method)
     end
 
     alias_method :==, :eql?
@@ -113,7 +109,5 @@ module Mocha
     def definition_target
       @definition_target ||= stubbee.__metaclass__
     end
-
   end
-
 end
