@@ -1,18 +1,17 @@
 require 'date'
 
 module Mocha
-
   module ObjectMethods
     def mocha_inspect
-      address = self.__id__ * 2
+      address = __id__ * 2
       address += 0x100000000 if address < 0
-      inspect =~ /#</ ? "#<#{self.class}:0x#{'%x' % address}>" : inspect
+      inspect =~ /#</ ? "#<#{self.class}:0x#{format('%x', address)}>" : inspect
     end
   end
 
   module ArrayMethods
     def mocha_inspect
-      "[#{collect { |member| member.mocha_inspect }.join(', ')}]"
+      "[#{collect(&:mocha_inspect).join(', ')}]"
     end
   end
 
@@ -33,7 +32,6 @@ module Mocha
       to_s
     end
   end
-
 end
 
 class Object
