@@ -9,9 +9,9 @@ require 'mocha/unexpected_invocation'
 require 'mocha/argument_iterator'
 require 'mocha/expectation_error_factory'
 require 'mocha/deprecation'
+require 'mocha/ruby_version'
 
 module Mocha
-
   # Traditional mock object.
   #
   # All methods return an {Expectation} which can be further modified by
@@ -68,7 +68,6 @@ module Mocha
   # different mock objects, use the {Expectation#in_sequence} method to
   # explicitly define a total or partial ordering of invocations.
   class Mock
-
     # Adds an expectation that the specified method must be called exactly once with any parameters.
     #
     # @param [Symbol,String] method_name name of expected method
@@ -105,13 +104,13 @@ module Mocha
     #   object.expects(:expected_method_two).returns(:result_two)
     def expects(method_name_or_hash, backtrace = nil)
       iterator = ArgumentIterator.new(method_name_or_hash)
-      iterator.each { |*args|
+      iterator.each do |*args|
         method_name = args.shift
         ensure_method_not_already_defined(method_name)
         expectation = Expectation.new(self, method_name, backtrace)
-        expectation.returns(args.shift) if args.length > 0
+        expectation.returns(args.shift) unless args.empty?
         @expectations.add(expectation)
-      }
+      end
     end
 
     # Adds an expectation that the specified method may be called any number of times with any parameters.
@@ -141,14 +140,14 @@ module Mocha
     #   object.stubs(:stubbed_method_two).returns(:result_two)
     def stubs(method_name_or_hash, backtrace = nil)
       iterator = ArgumentIterator.new(method_name_or_hash)
-      iterator.each { |*args|
+      iterator.each do |*args|
         method_name = args.shift
         ensure_method_not_already_defined(method_name)
         expectation = Expectation.new(self, method_name, backtrace)
         expectation.at_least(0)
-        expectation.returns(args.shift) if args.length > 0
+        expectation.returns(args.shift) unless args.empty?
         @expectations.add(expectation)
-      }
+      end
     end
 
     # Removes the specified stubbed method (added by calls to {#expects} or {#stubs}) and all expectations associated with it.
@@ -260,10 +259,9 @@ module Mocha
       @everything_stubbed = false
       @responder = nil
       @unexpected_invocation = nil
-      if block
-        Deprecation.warning('Passing a block is deprecated. Use Object#tap or define stubs/expectations with an explicit receiver instead.')
-        instance_eval(&block)
-      end
+      return unless block
+      Deprecation.warning('Passing a block is deprecated. Use Object#tap or define stubs/expectations with an explicit receiver instead.')
+      instance_eval(&block)
     end
 
     # @private
@@ -292,30 +290,30 @@ module Mocha
     end
 
     # @private
+    # rubocop:disable Style/MethodMissingSuper
     def method_missing(symbol, *arguments, &block)
-      if @responder and not @responder.respond_to?(symbol)
-        raise NoMethodError, "undefined method `#{symbol}' for #{self.mocha_inspect} which responds like #{@responder.mocha_inspect}"
+      if @responder && !@responder.respond_to?(symbol)
+        raise NoMethodError, "undefined method `#{symbol}' for #{mocha_inspect} which responds like #{@responder.mocha_inspect}"
       end
-      if matching_expectation_allowing_invocation = all_expectations.match_allowing_invocation(symbol, *arguments)
+      if (matching_expectation_allowing_invocation = all_expectations.match_allowing_invocation(symbol, *arguments))
         matching_expectation_allowing_invocation.invoke(&block)
-      else
-        if (matching_expectation = all_expectations.match(symbol, *arguments)) || (!matching_expectation && !@everything_stubbed)
-          if @unexpected_invocation.nil?
-            @unexpected_invocation = UnexpectedInvocation.new(self, symbol, *arguments)
-            matching_expectation.invoke(&block) if matching_expectation
-            message = @unexpected_invocation.full_description
-            message << @mockery.mocha_inspect
-          else
-            message = @unexpected_invocation.short_description
-          end
-          raise ExpectationErrorFactory.build(message, caller)
+      elsif (matching_expectation = all_expectations.match(symbol, *arguments)) || (!matching_expectation && !@everything_stubbed)
+        if @unexpected_invocation.nil?
+          @unexpected_invocation = UnexpectedInvocation.new(self, symbol, *arguments)
+          matching_expectation.invoke(&block) if matching_expectation
+          message = @unexpected_invocation.full_description
+          message << @mockery.mocha_inspect
+        else
+          message = @unexpected_invocation.short_description
         end
+        raise ExpectationErrorFactory.build(message, caller)
       end
     end
+    # rubocop:enable Style/MethodMissingSuper
 
     # @private
-    def respond_to?(symbol, include_private = false)
-      if @responder then
+    def respond_to_missing?(symbol, include_private = false)
+      if @responder
         if @responder.method(:respond_to?).arity > 1
           @responder.respond_to?(symbol, include_private)
         else
@@ -326,6 +324,13 @@ module Mocha
       end
     end
 
+    # @private
+    if PRE_RUBY_V19
+      def respond_to?(symbol, include_private = false)
+        respond_to_missing?(symbol, include_private)
+      end
+    end
+
     # @private
     def __verified__?(assertion_counter = nil)
       @expectations.verified?(assertion_counter)
@@ -343,14 +348,12 @@ module Mocha
 
     # @private
     def ensure_method_not_already_defined(method_name)
-      self.__metaclass__.send(:undef_method, method_name) if self.__metaclass__.method_defined?(method_name) || self.__metaclass__.private_method_defined?(method_name)
+      __metaclass__.send(:undef_method, method_name) if __metaclass__.method_defined?(method_name) || __metaclass__.private_method_defined?(method_name)
     end
 
     # @private
     def any_expectations?
       @expectations.any?
     end
-
   end
-
 end
