@@ -1,7 +1,5 @@
 module Mocha
-
   class ImpersonatingName
-
     def initialize(object)
       @object = object
     end
@@ -9,11 +7,9 @@ module Mocha
     def mocha_inspect
       @object.mocha_inspect
     end
-
   end
 
   class ImpersonatingAnyInstanceName
-
     def initialize(klass)
       @klass = klass
     end
@@ -21,11 +17,9 @@ module Mocha
     def mocha_inspect
       "#<AnyInstance:#{@klass.mocha_inspect}>"
     end
-
   end
 
   class Name
-
     def initialize(name)
       @name = name
     end
@@ -33,11 +27,9 @@ module Mocha
     def mocha_inspect
       "#<Mock:#{@name}>"
     end
-
   end
 
   class DefaultName
-
     def initialize(mock)
       @mock = mock
     end
@@ -45,9 +37,7 @@ module Mocha
     def mocha_inspect
       address = @mock.__id__ * 2
       address += 0x100000000 if address < 0
-      "#<Mock:0x#{'%x' % address}>"
+      "#<Mock:0x#{format('%x', address)}>"
     end
-
   end
-
 end
