@@ -1,3 +1,3 @@
-require "mocha/integration/test_unit"
+require 'mocha/integration/test_unit'
 
 Mocha::Integration::TestUnit.activate
