@@ -2,7 +2,6 @@ require File.expand_path('../acceptance_test_helper', __FILE__)
 require 'mocha/setup'
 
 class Bug18914Test < Mocha::TestCase
-
   include AcceptanceTest
 
   def setup
@@ -14,30 +13,26 @@ class Bug18914Test < Mocha::TestCase
   end
 
   class AlwaysEql
-
     def my_method
       true
     end
 
-    def ==(o)
+    def ==(_other)
       true
     end
 
-    def eql?(o)
+    def eql?(_other)
       true
     end
-
   end
 
   def test_should_not_allow_stubbing_of_non_mock_instance_disrupted_by_legitimate_overriding_of_eql_method
+    always_eql1 = AlwaysEql.new
+    always_eql1.stubs(:my_method).returns(false)
 
-    always_eql_1 = AlwaysEql.new
-    always_eql_1.stubs(:my_method).returns(false)
+    always_eql2 = AlwaysEql.new
+    always_eql2.stubs(:my_method).returns(false)
 
-    always_eql_2 = AlwaysEql.new
-    always_eql_2.stubs(:my_method).returns(false)
-
-    assert_equal false, always_eql_2.my_method
+    assert_equal false, always_eql2.my_method
   end
-
 end
