@@ -1,8 +1,7 @@
 require File.expand_path('../acceptance_test_helper', __FILE__)
-require 'mocha'
-
-class Bug21465Test < Test::Unit::TestCase
+require 'mocha/setup'
 
+class Bug21465Test < Mocha::TestCase
   include AcceptanceTest
 
   def setup
@@ -30,5 +29,4 @@ class Bug21465Test < Test::Unit::TestCase
     end
     assert_passed(test_result)
   end
-
 end
