@@ -2,7 +2,6 @@ require File.expand_path('../acceptance_test_helper', __FILE__)
 require 'mocha/setup'
 
 class MockTest < Mocha::TestCase
-
   include AcceptanceTest
 
   def setup
@@ -15,7 +14,7 @@ class MockTest < Mocha::TestCase
 
   def test_should_build_mock_and_explicitly_add_an_expectation_which_is_satisfied
     test_result = run_as_test do
-      foo = mock()
+      foo = mock
       foo.expects(:bar)
       foo.bar
     end
@@ -24,7 +23,7 @@ class MockTest < Mocha::TestCase
 
   def test_should_build_mock_and_explicitly_add_an_expectation_which_is_not_satisfied
     test_result = run_as_test do
-      foo = mock()
+      foo = mock
       foo.expects(:bar)
     end
     assert_failed(test_result)
@@ -96,5 +95,4 @@ class MockTest < Mocha::TestCase
     end
     assert_failed(test_result)
   end
-
 end
