@@ -2,7 +2,6 @@ require File.expand_path('../acceptance_test_helper', __FILE__)
 require 'mocha/setup'
 
 class PartialMockTest < Mocha::TestCase
-
   include AcceptanceTest
 
   def setup
@@ -15,8 +14,8 @@ class PartialMockTest < Mocha::TestCase
 
   def test_should_pass_if_all_expectations_are_satisfied
     test_result = run_as_test do
-      partial_mock_one = "partial_mock_one"
-      partial_mock_two = "partial_mock_two"
+      partial_mock_one = 'partial_mock_one'
+      partial_mock_two = 'partial_mock_two'
 
       partial_mock_one.expects(:first)
       partial_mock_one.expects(:second)
@@ -31,8 +30,8 @@ class PartialMockTest < Mocha::TestCase
 
   def test_should_fail_if_all_expectations_are_not_satisfied
     test_result = run_as_test do
-      partial_mock_one = "partial_mock_one"
-      partial_mock_two = "partial_mock_two"
+      partial_mock_one = 'partial_mock_one'
+      partial_mock_two = 'partial_mock_two'
 
       partial_mock_one.expects(:first)
       partial_mock_one.expects(:second)
@@ -43,5 +42,4 @@ class PartialMockTest < Mocha::TestCase
     end
     assert_failed(test_result)
   end
-
 end
