@@ -2,7 +2,6 @@ require File.expand_path('../acceptance_test_helper', __FILE__)
 require 'mocha/setup'
 
 class StubModuleMethodTest < Mocha::TestCase
-
   include AcceptanceTest
 
   def setup
@@ -13,6 +12,7 @@ class StubModuleMethodTest < Mocha::TestCase
     teardown_acceptance_test
   end
 
+  # rubocop:disable Lint/DuplicateMethods
   def test_should_stub_method_within_test
     mod = Module.new do
       def self.my_module_method
@@ -38,7 +38,7 @@ class StubModuleMethodTest < Mocha::TestCase
     run_as_test do
       mod.stubs(:my_module_method).returns(:new_return_value)
     end
-    assert mod.public_methods(false).any? { |m| m.to_s == 'my_module_method' }
+    assert(mod.public_methods(false).any? { |m| m.to_s == 'my_module_method' })
     assert_equal :original_return_value, mod.my_module_method
   end
 
@@ -57,7 +57,7 @@ class StubModuleMethodTest < Mocha::TestCase
     run_as_test do
       mod.stubs(:my_module_method).returns(:new_return_value)
     end
-    assert mod.protected_methods(false).any? { |m| m.to_s == 'my_module_method' }
+    assert(mod.protected_methods(false).any? { |m| m.to_s == 'my_module_method' })
     assert_equal :original_return_value, mod.my_unprotected_module_method
   end
 
@@ -73,7 +73,7 @@ class StubModuleMethodTest < Mocha::TestCase
     run_as_test do
       mod.stubs(:my_module_method).returns(:new_return_value)
     end
-    assert mod.private_methods(false).any? { |m| m.to_s == 'my_module_method' }
+    assert(mod.private_methods(false).any? { |m| m.to_s == 'my_module_method' })
     assert_equal :original_return_value, mod.send(:my_module_method)
   end
 
@@ -103,15 +103,15 @@ class StubModuleMethodTest < Mocha::TestCase
       assert_equal :new_return_value, mod.my_superclass_method
     end
     assert_passed(test_result)
-    assert supermod.public_methods.any? { |m| m.to_s == 'my_superclass_method' }
-    assert !mod.public_methods(false).any? { |m| m.to_s == 'my_superclass_method' }
+    assert(supermod.public_methods.any? { |m| m.to_s == 'my_superclass_method' })
+    assert(mod.public_methods(false).none? { |m| m.to_s == 'my_superclass_method' })
     assert_equal :original_return_value, supermod.my_superclass_method
   end
 
   def test_should_be_able_to_stub_method_if_ruby18_public_methods_include_method_but_method_does_not_actually_exist_like_active_record_association_proxy
     ruby18_mod = Module.new do
       class << self
-        def public_methods(include_superclass = true)
+        def public_methods(_include_superclass = true)
           ['my_module_method']
         end
       end
@@ -126,7 +126,7 @@ class StubModuleMethodTest < Mocha::TestCase
   def test_should_be_able_to_stub_method_if_ruby19_public_methods_include_method_but_method_does_not_actually_exist_like_active_record_association_proxy
     ruby19_mod = Module.new do
       class << self
-        def public_methods(include_superclass = true)
+        def public_methods(_include_superclass = true)
           [:my_module_method]
         end
       end
@@ -141,7 +141,7 @@ class StubModuleMethodTest < Mocha::TestCase
   def test_should_be_able_to_stub_method_if_ruby_18_protected_methods_include_method_but_method_does_not_actually_exist_like_active_record_association_proxy
     ruby18_mod = Module.new do
       class << self
-        def protected_methods(include_superclass = true)
+        def protected_methods(_include_superclass = true)
           ['my_module_method']
         end
       end
@@ -156,7 +156,7 @@ class StubModuleMethodTest < Mocha::TestCase
   def test_should_be_able_to_stub_method_if_ruby19_protected_methods_include_method_but_method_does_not_actually_exist_like_active_record_association_proxy
     ruby19_mod = Module.new do
       class << self
-        def protected_methods(include_superclass = true)
+        def protected_methods(_include_superclass = true)
           [:my_module_method]
         end
       end
@@ -171,7 +171,7 @@ class StubModuleMethodTest < Mocha::TestCase
   def test_should_be_able_to_stub_method_if_ruby18_private_methods_include_method_but_method_does_not_actually_exist_like_active_record_association_proxy
     ruby18_mod = Module.new do
       class << self
-        def private_methods(include_superclass = true)
+        def private_methods(_include_superclass = true)
           ['my_module_method']
         end
       end
@@ -186,7 +186,7 @@ class StubModuleMethodTest < Mocha::TestCase
   def test_should_be_able_to_stub_method_if_ruby19_private_methods_include_method_but_method_does_not_actually_exist_like_active_record_association_proxy
     ruby19_mod = Module.new do
       class << self
-        def private_methods(include_superclass = true)
+        def private_methods(_include_superclass = true)
           [:my_module_method]
         end
       end
@@ -197,5 +197,5 @@ class StubModuleMethodTest < Mocha::TestCase
     end
     assert_passed(test_result)
   end
-
+  # rubocop:enable Lint/DuplicateMethods
 end
