@@ -3,7 +3,6 @@ require 'mocha/setup'
 require 'execution_point'
 
 class StubbaTestResultTest < Mocha::TestCase
-
   include AcceptanceTest
 
   def setup
@@ -17,8 +16,7 @@ class StubbaTestResultTest < Mocha::TestCase
   def test_should_include_expectation_verification_in_assertion_count
     test_result = run_as_test do
       object = Class.new do
-        def message
-        end
+        def message; end
       end.new
       object.expects(:message)
       object.message
@@ -36,8 +34,7 @@ class StubbaTestResultTest < Mocha::TestCase
   def test_should_not_include_stubbing_expectation_verification_in_assertion_count
     test_result = run_as_test do
       object = Class.new do
-        def message
-        end
+        def message; end
       end.new
       object.stubs(:message)
       object.message
@@ -48,8 +45,7 @@ class StubbaTestResultTest < Mocha::TestCase
   def test_should_include_expectation_verification_failure_in_failure_count
     test_result = run_as_test do
       object = Class.new do
-        def message
-        end
+        def message; end
       end.new
       object.expects(:message)
     end
@@ -63,6 +59,7 @@ class StubbaTestResultTest < Mocha::TestCase
     assert_equal 1, test_result.failure_count
   end
 
+  # rubocop:disable Style/Semicolon
   def test_should_display_backtrace_indicating_line_number_where_failing_assertion_was_called
     execution_point = nil
     test_result = run_as_test do
@@ -71,5 +68,5 @@ class StubbaTestResultTest < Mocha::TestCase
     assert_equal 1, test_result.failure_count
     assert_equal execution_point, ExecutionPoint.new(test_result.failures[0].location)
   end
-
+  # rubocop:enable Style/Semicolon
 end
