@@ -2,7 +2,6 @@ require File.expand_path('../acceptance_test_helper', __FILE__)
 require 'mocha/setup'
 
 class StubbingNonExistentAnyInstanceMethodTest < Mocha::TestCase
-
   include AcceptanceTest
 
   def setup
@@ -67,7 +66,7 @@ class StubbingNonExistentAnyInstanceMethodTest < Mocha::TestCase
   def test_should_allow_stubbing_method_to_which_any_instance_responds
     Mocha::Configuration.prevent(:stubbing_non_existent_method)
     klass = Class.new do
-      def respond_to?(method, include_private = false)
+      def respond_to?(method, _include_private = false)
         (method == :method_to_which_instance_responds)
       end
     end
@@ -139,5 +138,4 @@ class StubbingNonExistentAnyInstanceMethodTest < Mocha::TestCase
     end
     assert_passed(test_result)
   end
-
 end
