@@ -1,8 +1,7 @@
 require File.expand_path('../acceptance_test_helper', __FILE__)
-require 'mocha'
-
-class ThrowTest < Test::Unit::TestCase
+require 'mocha/setup'
 
+class ThrowTest < Mocha::TestCase
   include AcceptanceTest
 
   def setup
@@ -41,5 +40,4 @@ class ThrowTest < Test::Unit::TestCase
     end
     assert_passed(test_result)
   end
-
 end
