@@ -2,7 +2,6 @@ require File.expand_path('../acceptance_test_helper', __FILE__)
 require 'mocha/setup'
 
 class UnexpectedInvocationTest < Mocha::TestCase
-
   include AcceptanceTest
 
   def setup
@@ -20,6 +19,6 @@ class UnexpectedInvocationTest < Mocha::TestCase
       instance.inspect(1, 2, 'foo')
     end
     assert_failed(test_result)
-    assert_equal "unexpected invocation: inspect(1, 2, foo)", test_result.failure_message_lines[0]
+    assert_equal 'unexpected invocation: inspect(1, 2, foo)', test_result.failure_message_lines[0]
   end
-end
\ No newline at end of file
+end
