@@ -1,29 +1,38 @@
 require 'stringio'
-require 'test/unit/testcase'
 require 'minitest/unit'
 
 class MiniTestResult
-
-  FAILURE_PATTERN = %r{(Failure)\:\n([^\(]+)\(([^\)]+)\) \[([^\]]+)\]\:\n(.*)\n}m
-  ERROR_PATTERN   = %r{(Error)\:\n([^\(]+)\(([^\)]+)\)\:\n(.+?)\n}m
+  minitest_version = Gem::Version.new(::MiniTest::Unit::VERSION)
+  if Gem::Requirement.new('<= 4.6.1').satisfied_by?(minitest_version)
+    FAILURE_PATTERN = /(Failure)\:\n([^\(]+)\(([^\)]+)\) \[([^\]]+)\]\:\n(.*)\n/m
+    ERROR_PATTERN   = /(Error)\:\n([^\(]+)\(([^\)]+)\)\:\n(.+?)\n/m
+    PATTERN_INDICES = { :method => 2, :testcase => 3 }.freeze
+  else
+    FAILURE_PATTERN = /(Failure)\:\n.([^#]+)\#([^ ]+) \[([^\]]+)\]\:\n(.*)\n/m
+    ERROR_PATTERN   = /(Error)\:\n.([^#]+)\#([^ ]+)\:\n(.+?)\n/m
+    PATTERN_INDICES = { :method => 3, :testcase => 2 }.freeze
+  end
 
   def self.parse_failure(raw)
     matches = FAILURE_PATTERN.match(raw)
     return nil unless matches
-    Failure.new(matches[2], matches[3], [matches[4]], matches[5])
+    Failure.new(matches[PATTERN_INDICES[:method]], matches[PATTERN_INDICES[:testcase]], [matches[4]], matches[5])
   end
 
   def self.parse_error(raw)
     matches = ERROR_PATTERN.match(raw)
     return nil unless matches
     backtrace = raw.gsub(ERROR_PATTERN, '').split("\n").map(&:strip)
-    Error.new(matches[2], matches[3], matches[4], backtrace)
+    Error.new(matches[PATTERN_INDICES[:method]], matches[PATTERN_INDICES[:testcase]], matches[4], backtrace)
   end
 
   class Failure
     attr_reader :method, :test_case, :location, :message
     def initialize(method, test_case, location, message)
-      @method, @test_case, @location, @message = method, test_case, location, message
+      @method = method
+      @test_case = test_case
+      @location = location
+      @message = message
     end
   end
 
@@ -31,18 +40,22 @@ class MiniTestResult
     class Exception
       attr_reader :message, :backtrace
       def initialize(message, location)
-        @message, @backtrace = message, location
+        @message = message
+        @backtrace = location
       end
     end
 
     attr_reader :method, :test_case, :exception
     def initialize(method, test_case, message, backtrace)
-      @method, @test_case, @exception = method, test_case, Exception.new(message, backtrace)
+      @method = method
+      @test_case = test_case
+      @exception = Exception.new(message, backtrace)
     end
   end
 
   def initialize(runner, tests)
-    @runner, @tests = runner, tests
+    @runner = runner
+    @tests = tests
   end
 
   def failure_count
