@@ -4,19 +4,18 @@ require 'mocha/mock'
 require 'mocha/any_instance_method'
 
 class AnyInstanceMethodTest < Mocha::TestCase
-
   include Mocha
 
-unless RUBY_V2_PLUS
-  def test_should_hide_original_method
-    klass = Class.new { def method_x; end }
-    method = AnyInstanceMethod.new(klass, :method_x)
+  unless RUBY_V2_PLUS
+    def test_should_hide_original_method
+      klass = Class.new { def method_x; end }
+      method = AnyInstanceMethod.new(klass, :method_x)
 
-    method.hide_original_method
+      method.hide_original_method
 
-    assert_equal false, klass.method_defined?(:method_x)
+      assert_equal false, klass.method_defined?(:method_x)
+    end
   end
-end
 
   def test_should_not_raise_error_hiding_method_that_isnt_defined
     klass = Class.new
@@ -45,7 +44,11 @@ end
   end
 
   def test_should_restore_original_method
-    klass = Class.new { def method_x; :original_result; end }
+    klass = Class.new do
+      def method_x
+        :original_result
+      end
+    end
     method = AnyInstanceMethod.new(klass, :method_x)
 
     method.hide_original_method
@@ -59,7 +62,11 @@ end
   end
 
   def test_should_not_restore_original_method_if_none_was_defined_in_first_place
-    klass = Class.new { def method_x; :new_result; end }
+    klass = Class.new do
+      def method_x
+        :new_result
+      end
+    end
     method = AnyInstanceMethod.new(klass, :method_x)
 
     method.restore_original_method
@@ -75,8 +82,8 @@ end
     any_instance.stubs(:mocha).returns(any_instance_mocha)
     klass.define_instance_method(:any_instance) { any_instance }
     method = AnyInstanceMethod.new(klass, :method_x)
-    method.replace_instance_method(:restore_original_method) { }
-    method.replace_instance_method(:reset_mocha) { }
+    method.replace_instance_method(:restore_original_method) {}
+    method.replace_instance_method(:reset_mocha) {}
     method.define_instance_accessor(:remove_called)
     method.replace_instance_method(:remove_new_method) { self.remove_called = true }
 
@@ -92,8 +99,8 @@ end
     any_instance.stubs(:mocha).returns(any_instance_mocha)
     klass.define_instance_method(:any_instance) { any_instance }
     method = AnyInstanceMethod.new(klass, :method_x)
-    method.replace_instance_method(:remove_new_method) { }
-    method.replace_instance_method(:reset_mocha) { }
+    method.replace_instance_method(:remove_new_method) {}
+    method.replace_instance_method(:reset_mocha) {}
     method.define_instance_accessor(:restore_called)
     method.replace_instance_method(:restore_original_method) { self.restore_called = true }
 
@@ -107,9 +114,16 @@ end
 
     method = AnyInstanceMethod.new(klass, :method_x)
 
-    method.replace_instance_method(:remove_new_method) { }
-    method.replace_instance_method(:restore_original_method) { }
-    mocha = Class.new { class << self; attr_accessor :unstub_method; end; def self.unstub(method); self.unstub_method = method; end; }
+    method.replace_instance_method(:remove_new_method) {}
+    method.replace_instance_method(:restore_original_method) {}
+    mocha = Class.new do
+      class << self
+        attr_accessor :unstub_method
+      end
+      def self.unstub(method)
+        self.unstub_method = method
+      end
+    end
     mocha.define_instance_method(:any_expectations?) { true }
     method.replace_instance_method(:mock) { mocha }
 
