@@ -1,25 +1,42 @@
 require File.expand_path('../../test_helper', __FILE__)
 require 'mocha/object_methods'
+require 'mocha/mockery'
 require 'mocha/mock'
 require 'mocha/expectation_error_factory'
+require 'mocha/names'
 
 class ObjectMethodsTest < Mocha::TestCase
-
   def setup
+    Mocha::Mockery.setup
     @object = Object.new.extend(Mocha::ObjectMethods)
   end
 
+  def teardown
+    Mocha::Mockery.teardown
+  end
+
   def test_should_build_mocha_referring_to_self
     mocha = @object.mocha
     assert_not_nil mocha
     assert mocha.is_a?(Mocha::Mock)
-    assert_equal @object.mocha_inspect, mocha.mocha_inspect
+    expected_name = Mocha::ImpersonatingName.new(@object).mocha_inspect
+    assert_equal expected_name, mocha.mocha_inspect
+  end
+
+  def test_should_not_build_mocha_if_instantiate_is_false
+    assert_nil @object.mocha(false)
   end
 
   def test_should_reuse_existing_mocha
-    mocha_1 = @object.mocha
-    mocha_2 = @object.mocha
-    assert_equal mocha_1, mocha_2
+    mocha1 = @object.mocha
+    mocha2 = @object.mocha
+    assert_equal mocha1, mocha2
+  end
+
+  def test_should_reuse_existing_mocha_even_if_instantiate_is_false
+    mocha1 = @object.mocha
+    mocha2 = @object.mocha(false)
+    assert_equal mocha1, mocha2
   end
 
   def test_should_reset_mocha
@@ -42,5 +59,4 @@ class ObjectMethodsTest < Mocha::TestCase
     klass = Class.new { def self.method_x; end }
     assert_equal klass._method(:method_x), klass.method(:method_x)
   end
-
 end
