@@ -5,7 +5,6 @@ require 'mocha/parameter_matchers/object'
 require 'mocha/inspect'
 
 class RespondsWithTest < Mocha::TestCase
-
   include Mocha::ParameterMatchers
 
   def test_should_match_parameter_responding_with_expected_value
@@ -20,7 +19,15 @@ class RespondsWithTest < Mocha::TestCase
 
   def test_should_match_parameter_responding_with_nested_responds_with_matcher
     matcher = responds_with(:foo, responds_with(:bar, 'baz'))
-    object = Class.new { def foo; Class.new { def bar; 'baz'; end }.new; end }.new
+    object = Class.new do
+      def foo
+        Class.new do
+          def bar
+            'baz'
+          end
+        end.new
+      end
+    end.new
     assert matcher.matches?([object])
   end
 
@@ -28,5 +35,4 @@ class RespondsWithTest < Mocha::TestCase
     matcher = responds_with(:foo, :bar)
     assert_equal 'responds_with(:foo, :bar)', matcher.mocha_inspect
   end
-
 end
