@@ -2,8 +2,7 @@ require File.expand_path('../../test_helper', __FILE__)
 
 require 'mocha/single_yield'
 
-class SingleYieldTest < Test::Unit::TestCase
-  
+class SingleYieldTest < Mocha::TestCase
   include Mocha
 
   def test_should_provide_parameters_for_single_yield_in_single_invocation
@@ -14,5 +13,4 @@ class SingleYieldTest < Test::Unit::TestCase
     end
     assert_equal [[1, 2, 3]], parameter_groups
   end
-  
 end
